# jc-distribution package 

This package contains classes to build Gaussian and Binomial distributions

#files

license.txt
readme.md
setup.py

distributions\
__init__.py
Generaldistribution.py
Gaussiandistribution.py
Generaldistribution.py

#installation